@@ -12,6 +12,8 @@ HELP_TEXT = """\
 Welcome to PuDB, the Python Urwid debugger.
 -------------------------------------------
 
+(This help screen is scrollable. Hit Page Down to see more.)
+
 Keys:
     Ctrl-p - edit preferences
 
@@ -35,7 +37,7 @@ Keys:
     ctrl-u/d - page up/down
     h/l - scroll left/right
     g/G - start/end
-    L - go to line
+    L - show (file/line) location / go to line
     / - search
     ,/. - search next/previous
 
@@ -1240,7 +1242,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                         "Syntax highlighting disabled.")
 
         from pudb import CONFIG
-        WELCOME_LEVEL = "e002"
+        WELCOME_LEVEL = "e003"
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -1254,6 +1256,8 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "look familiar.\n\n"
                     "If you're new here, welcome! The help screen (invoked by hitting "
                     "'?' after this message) should get you on your way.\n"
+                    "\nNew features in version 2011.3.1:\n\n"
+                    "- Work-aroudn for bug in urwid >= 1.0.\n"
                     "\nNew features in version 2011.3:\n\n"
                     "- Finer-grained string highlighting (submitted by Aaron Meurer)\n"
                     "- Prefs tweaks, instant-apply, top-down stack (submitted by Aaron Meurer)\n"
