@@ -1,4 +1,4 @@
-THEMES = ["classic", "vim", "dark vim"]
+THEMES = ["classic", "vim", "dark vim", "midnight"]
 
 
 
@@ -80,7 +80,7 @@ def get_palette(may_use_fancy_formats, theme="classic"):
         ("label", "black", "light gray"),
         ("value", "yellow", "dark blue"),
         ("fixed value", "light gray", "dark blue"),
-        ("group head", add_setting("black", "bold"), "light gray"),
+        ("group head", add_setting("dark blue", "bold"), "light gray"),
 
         ("search box", "black", "dark cyan"),
         ("search not found", "white", "dark red"),
@@ -99,6 +99,12 @@ def get_palette(may_use_fancy_formats, theme="classic"):
         ("keyword", add_setting("white", "bold"), "dark blue"),
         ("name", "light cyan", "dark blue"),
         ("literal", "light magenta", "dark blue"),
+
+        ("string", "light magenta", "dark blue"),
+        ("doublestring", "light magenta", "dark blue"),
+        ("singlestring", "light magenta", "dark blue"),
+        ("docstring", "light magenta", "dark blue"),
+
         ("punctuation", "light gray", "dark blue"),
         ("comment", "light gray", "dark blue"),
         ("bp_star", "dark red", "dark blue"),
@@ -115,8 +121,13 @@ def get_palette(may_use_fancy_formats, theme="classic"):
             "source": ("black", "default"),
             "keyword": ("brown", "default"),
             "kw_namespace": ("dark magenta", "default"),
+
             "literal": ("black", "default"),
             "string": ("dark red", "default"),
+            "doublestring": ("dark red", "default"),
+            "singlestring": ("dark red", "default"),
+            "docstring": ("dark red", "default"),
+
             "punctuation": ("black", "default"),
             "comment": ("dark blue", "default"),
             "classname": ("dark cyan", "default"),
@@ -137,8 +148,8 @@ def get_palette(may_use_fancy_formats, theme="classic"):
         "focused var label": ("light gray", "light blue"),
         "focused var value": ("white", "light blue"),
 
-        "highlighted var label": ("light gray", "light green"),
-        "highlighted var value": ("white", "light green"),
+        "highlighted var label": ("light gray", "dark green"),
+        "highlighted var value": ("white", "dark green"),
         "focused highlighted var label": ("light gray", "light blue"),
         "focused highlighted var value": ("white", "light blue"),
 
@@ -210,19 +221,72 @@ def get_palette(may_use_fancy_formats, theme="classic"):
 
         "line number": ("dark gray", "black"),
         "keyword": ("yellow", "black"),
+
         "literal": ("dark magenta", "black"),
+        "string": ("dark magenta", "black"),
+        "doublestring": ("dark magenta", "black"),
+        "singlestring": ("dark magenta", "black"),
+        "docstring": ("dark magenta", "black"),
+
         "name": ("light cyan", "black"),
         "punctuation": ("yellow", "black"),
         "comment": ("light blue", "black"),
         "bp_star": ("dark red", "black"),
             })
+    elif theme == "midnight":
+        # Based on XCode's midnight theme
+        # Looks best in a console with green text against black background
+        palette_dict.update({
+            "variables": ("white", "default"),
+
+            "var label": ("light blue", "default"),
+            "var value": ("white", "default"),
+
+            "stack": ("white", "default"),
+
+            "frame name": ("white", "default"),
+            "frame class": ("dark blue", "default"),
+            "frame location": ("light cyan", "default"),
+
+            "current frame name": (add_setting("white", "bold"), "default"),
+            "current frame class": ("dark blue", "default"),
+            "current frame location": ("light cyan", "default"),
+
+            "breakpoint": ("default", "default"),
+
+            "search box": ("default", "default"),
+
+            "source": ("white", "default"),
+            "highlighted source": ("white", "light cyan"),
+            "current source": ("white", "light gray"),
+            "current focused source": ("white", "brown"),
+
+            "line number": ("light gray", "default"),
+            "keyword": ("dark magenta", "default"),
+            "name": ("white", "default"),
+            "literal": ("dark cyan", "default"),
+            "string": ("dark red", "default"),
+            "doublestring": ("dark red", "default"),
+            "singlestring": ("light blue", "default"),
+            "docstring": ("light red", "default"),
+            "backtick": ("light green", "default"),
+            "punctuation": ("white", "default"),
+            "comment": ("dark green", "default"),
+            "classname": ("dark cyan", "default"),
+            "funcname": ("white", "default"),
+            "bp_star": ("dark red", "default"),
+
+        })
+
     else:
         try:
             symbols = {
                     "palette": palette_dict,
                     "add_setting": add_setting,
                     }
-            execfile(theme, symbols)
+
+            from os.path import expanduser
+            execfile(expanduser(theme), symbols)
         except:
             print "Error when importing theme:"
             from traceback import print_exc
